"Ag nanoparticle" "HAADF-STEM" : nature.com search

Skip to main content

Advertisement

Thank you for visiting nature.com. You are using a browser version with limited support for CSS. To obtain the best experience, we recommend you use a more up to date browser (or turn off compatibility mode in Internet Explorer). In the meantime, to ensure continued support, we are displaying the site without styles and JavaScript.

Menu

#

Search My Account Login
Search
advanced
where the list of authors contains where the title contains

## Refine your results by…

volume
start page / article no.

## Filters ​

## Filter By:

Article type ​
Check one or more article types to show results from those article types only.

- Research (12)

Journal ​​
Check one or more journals to show results from those journals only.

- Nature Communications (5)
- Scientific Reports (3)
- Nature Catalysis (1)
- Nature Chemistry (1)
- Nature Materials (1)

Choose more journals

Subject Check one or more subjects to show results from those subjects only.

- Nanoparticles (4)
- Electrochemistry (2)
- Electronic devices (2)
- Heterogeneous catalysis (2)
- Nanoscale materials (2)

Date ​
Choose a date option to show results from those dates only.

- Today
- Last 7 days
- Last 30 days
- In the last year
- Last 2 years
- Last 5 years

Custom date range

Sort by Relevance ​​
Choose a way to sort results.

- Relevance
- Date — most recent
- Date — oldest first

Loading Filters

Showing 1–12 of 12 results

Loading Filters

1. Research | 13 September 2018 | Open

   ## Seed-mediated atomic-scale reconstruction of silver manganate nanoplates for oxygen reduction towards high-energy aluminum-air flow batteries

   - Jaechan Ryu
   - , Haeseong Jang
   - , Joohyuk Park
   - , Youngshin Yoo
   - , Minjoon Park
   - & Jaephil Cho
   Nature Communications 9 , 1–10
   Rights & permissionsfor article Seed-mediated atomic-scale reconstruction of silver manganate nanoplates for oxygen reduction towards high-energy aluminum-air flow batteries . Opens in a new window.

2. Research | 11 September 2014

   ## In situ liquid-cell electron microscopy of silver–palladium galvanic replacement reactions on silver nanoparticles

   - E. Sutter
   - , K. Jungjohann
   - , S. Bliznakov
   - , A. Courty
   - , E. Maisonhaute
   - , S. Tenney
   - & P. Sutter
   Nature Communications 5 , 1–9
   Rights & permissionsfor article <i>In situ</i> liquid-cell electron microscopy of silver–palladium galvanic replacement reactions on silver nanoparticles . Opens in a new window.

3. Research | 24 February 2020

   ## Interface-mediated noble metal deposition on transition metal dichalcogenide nanostructures

   - Yifan Sun
   - , Yuanxi Wang
   - , Jamie Y. C. Chen
   - , Kazunori Fujisawa
   - , Cameron F. Holder
   - , Jeffery T. Miller
   - , Vincent H. Crespi
   - , Mauricio Terrones
   - & Raymond E. Schaak
   Nature Chemistry 12 , 284–293
   Rights & permissionsfor article Interface-mediated noble metal deposition on transition metal dichalcogenide nanostructures . Opens in a new window.

4. Research | 21 October 2012

   ## Atomic-scale determination of surface facets in gold nanorods

   - Bart Goris
   - , Sara Bals
   - , Wouter Van den Broek
   - , Enrique Carbó-Argibay
   - , Sergio Gómez-Graña
   - , Luis M. Liz-Marzán
   - & Gustaaf Van Tendeloo
   Nature Materials 11 , 930–935
   Rights & permissionsfor article Atomic-scale determination of surface facets in gold nanorods . Opens in a new window.

5. Research | 14 October 2019

   ## A silver catalyst activated by stacking faults for the hydrogen evolution reaction

   - Zhe Li
   - , Jian-Yu Fu
   - , Yi Feng
   - , Cun-Ku Dong
   - , Hui Liu
   - & Xi-Wen Du
   Nature Catalysis 2 , 1107–1114
   Rights & permissionsfor article A silver catalyst activated by stacking faults for the hydrogen evolution reaction . Opens in a new window.

6. Research | 3 December 2014

   ## FeOx-supported platinum single-atom and pseudo-single-atom catalysts for chemoselective hydrogenation of functionalized nitroarenes

   - Haisheng Wei
   - , Xiaoyan Liu
   - , Aiqin Wang
   - , Leilei Zhang
   - , Botao Qiao
   - , Xiaofeng Yang
   - , Yanqiang Huang
   - , Shu Miao
   - , Jingyue Liu
   - & Tao Zhang
   Nature Communications 5 , 1–8
   Rights & permissionsfor article FeO<sub>x</sub>-supported platinum single-atom and pseudo-single-atom catalysts for chemoselective hydrogenation of functionalized nitroarenes . Opens in a new window.

7. Research | 22 September 2017 | Open

   ## Aligned hierarchical Ag/ZnO nano-heterostructure arrays via electrohydrodynamic nanowire template for enhanced gas-sensing properties

   - Zhouping Yin
   - , Xiaomei Wang
   - , Fazhe Sun
   - , Xiaohu Tong
   - , Chen Zhu
   - , Qiying Lv
   - , Dong Ye
   - , Shuai Wang
   - , Wei Luo
   - & YongAn Huang
   Scientific Reports 7 , 1–10
   Rights & permissionsfor article Aligned hierarchical Ag/ZnO nano-heterostructure arrays via electrohydrodynamic nanowire template for enhanced gas-sensing properties . Opens in a new window.

8. Research | 13 March 2012

   ## Observation of conducting filament growth in nanoscale resistive memories

   - Yuchao Yang
   - , Peng Gao
   - , Siddharth Gaba
   - , Ting Chang
   - , Xiaoqing Pan
   - & Wei Lu
   Nature Communications 3 , 1–8
   Rights & permissionsfor article Observation of conducting filament growth in nanoscale resistive memories . Opens in a new window.

9. Research | 1 April 2007

   ## Mapping surface plasmons on a single metallic nanoparticle

   - Jaysen Nelayah
   - , Mathieu Kociak
   - , Odile Stéphan
   - , F. Javier García de Abajo
   - , Marcel Tencé
   - , Luc Henrard
   - , Dario Taverna
   - , Isabel Pastoriza-Santos
   - , Luis M. Liz-Marzán
   - & Christian Colliex
   Nature Physics 3 , 348–353
   Rights & permissionsfor article Mapping surface plasmons on a single metallic nanoparticle . Opens in a new window.

10. Research | 5 November 2015 | Open

    ## Multipole plasmons and their disappearance in few-nanometre silver nanoparticles

    - Søren Raza
    - , Shima Kadkhodazadeh
    - , Thomas Christensen
    - , Marcel Di Vece
    - , Martijn Wubs
    - , N. Asger Mortensen
    - & Nicolas Stenger
    Nature Communications 6 , 1–9
    Rights & permissionsfor article Multipole plasmons and their disappearance in few-nanometre silver nanoparticles . Opens in a new window.

11. Research | 20 March 2013 | Open

    ## Core–Shell Bimetallic Nanoparticles Robustly Fixed on the Outermost Surface of Magnetic Silica Microspheres

    - Hye Hun Park
    - , Kyoungja Woo
    - & Jae-Pyoung Ahn
    Scientific Reports 3 , 1–7
    Rights & permissionsfor article Core–Shell Bimetallic Nanoparticles Robustly Fixed on the Outermost Surface of Magnetic Silica Microspheres . Opens in a new window.

12. Research | 7 April 2016 | Open

    ## Dual-functional Memory and Threshold Resistive Switching Based on the Push-Pull Mechanism of Oxygen Ions

    - Yi-Jen Huang
    - , Shih-Chun Chao
    - , Der-Hsien Lien
    - , Cheng-Yen Wen
    - , Jr-Hau He
    - & Si-Chen Lee
    Scientific Reports 6 , 1–10
    Rights & permissionsfor article Dual-functional Memory and Threshold Resistive Switching Based on the Push-Pull Mechanism of Oxygen Ions . Opens in a new window.